#line 2 "llsphinxql.c"

#line 4 "llsphinxql.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin ,yyscanner )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart (FILE *input_file ,yyscan_t yyscanner );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size ,yyscan_t yyscanner );
void yy_delete_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void yy_flush_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
void yypop_buffer_state (yyscan_t yyscanner );

static void yyensure_buffer_stack (yyscan_t yyscanner );
static void yy_load_buffer_state (yyscan_t yyscanner );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file ,yyscan_t yyscanner );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER ,yyscanner)

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len ,yyscan_t yyscanner );

void *yyalloc (yy_size_t ,yyscan_t yyscanner );
void *yyrealloc (void *,yy_size_t ,yyscan_t yyscanner );
void yyfree (void * ,yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state (yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  ,yyscan_t yyscanner);
static int yy_get_next_buffer (yyscan_t yyscanner );
static void yy_fatal_error (yyconst char msg[] ,yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;

#define YY_NUM_RULES 96
#define YY_END_OF_BUFFER 97
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[374] =
    {   0,
        0,    0,    0,    0,   97,   95,   94,   94,   95,   95,
       85,   95,   86,   95,   95,   95,   95,   90,   90,   90,
       90,   90,   90,   90,   90,   90,   90,   90,   90,   90,
       90,   90,   90,   90,   90,   95,    2,   96,    2,   94,
       79,    0,   84,    0,   85,    1,   85,   86,   83,   81,
       80,   82,    0,   91,   91,   91,   91,   90,   90,    5,
       90,   90,   90,   11,   90,   90,   90,   90,   90,   90,
       90,   90,   90,   90,   90,   90,   31,   32,   90,   90,
       90,   90,   90,   90,   90,   90,   90,   90,   90,   49,
       90,   90,   90,   90,   90,   90,   90,   90,   90,   90,

       68,   90,   90,   90,   90,   90,   90,   90,   90,    0,
        3,    0,   92,   91,   91,   87,   91,    4,    6,   90,
        8,   90,   90,   90,   90,   90,   90,   90,   90,   90,
       90,   22,   90,   90,   90,   90,   90,   90,   90,   90,
       90,   90,   35,   90,   90,   90,   90,   41,   90,   43,
       44,   90,   46,   90,   90,   90,   90,   90,   90,   90,
       90,   90,   90,   90,   90,   60,   90,   90,   90,   66,
       90,   90,   90,   90,   90,   90,   90,   90,   90,   90,
       90,    0,   93,   92,   91,   91,   90,   90,   90,   12,
       90,   90,   90,   90,   90,   19,   90,   23,   90,   90,

       90,   27,   90,   90,   90,   90,   90,   36,   90,   90,
       90,   90,   42,   90,   47,   90,   90,   51,   52,   90,
       90,   90,   90,   90,   90,   90,   90,   62,   90,   90,
       90,   90,   90,   70,   90,   90,   90,   90,   90,   90,
       90,   90,   91,   91,   90,    9,   90,   90,   90,   16,
       90,   90,   90,   90,   24,   25,   26,   90,   90,   30,
       33,   90,   90,   38,   39,   40,   45,   90,   50,   90,
       90,   90,   90,   90,   90,   90,   90,   90,   64,   90,
       90,   90,   90,   90,   90,   90,   90,   90,   77,   90,
       89,   91,    7,   90,   90,   14,   17,   18,   90,   90,

       90,   29,   34,   90,   48,   90,   90,   90,   90,   90,
       58,   90,   90,   63,   65,   67,   90,   90,   72,   73,
       90,   90,   76,   78,   88,   10,   90,   90,   90,   90,
       90,   90,   90,   54,   55,   90,   57,   90,   61,   90,
       90,   90,   90,   90,   90,   20,   21,   28,   90,   90,
       56,   90,   90,   90,   90,   75,   13,   15,   37,   90,
       90,   90,   90,   74,   53,   90,   90,   90,   90,   69,
       71,   59,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    1,    1,    1,    1,    1,    5,    1,
        1,    6,    1,    1,    1,    7,    8,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,   10,    1,   11,
       12,   13,    1,   14,   15,   16,   17,   18,   19,   20,
       21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
       24,   31,   32,   33,   34,   35,   36,   37,   38,   39,
        1,   40,    1,    1,   24,   41,   42,   43,   44,   45,

       46,   47,   48,   49,   50,   24,   51,   52,   53,   54,
       55,   56,   24,   57,   58,   59,   60,   61,   62,   63,
       64,   65,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[66] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    1,
        1,    1,    1,    3,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    1,
        5,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4
    } ;

static yyconst flex_int16_t yy_base[383] =
    {   0,
        0,    0,   63,   64,  210,  769,   69,   71,  194,   63,
      188,  183,   68,  175,   66,  144,   66,   53,   63,   75,
       74,    0,  103,   69,  107,   73,  125,  128,  116,  149,
      190,  161,  123,  100,  179,    0,  769,  769,  142,   96,
      769,   82,  769,   73,  140,  769,  132,  129,  769,  769,
      769,  769,    0,    0,  104,  140,  147,    0,  151,  167,
      141,  165,  184,    0,  155,  188,  180,  201,  199,  191,
      204,  208,  206,  210,  215,  218,    0,  233,  225,  220,
      231,  234,  229,  241,  234,  245,  241,  249,  243,  259,
      254,  279,  259,  260,  287,  260,  262,  272,  269,  283,

        0,  290,  286,  288,  297,  286,  284,  306,  294,   67,
      769,  324,    0,    0,  297,    0,  313,    0,    0,  325,
        0,  318,  311,  322,  325,  328,  328,  327,  339,  342,
      328,    0,  332,  333,  351,  338,  344,  355,  359,  344,
      357,  360,  354,  358,  361,  366,  373,    0,  377,    0,
        0,  375,    0,  372,  372,  381,  383,  387,  389,  377,
      386,  385,  399,  397,  382,    0,  387,  410,  398,    0,
      404,  405,  407,  405,  421,  408,  420,  418,  423,  417,
      428,   53,  769,    0,  426,  430,  441,  433,  443,    0,
      449,  442,  434,  436,  440,  444,  453,    0,  460,  448,

      460,    0,  451,  471,  458,  453,  463,    0,  481,  472,
      467,  480,    0,  472,    0,  476,  477,    0,    0,  496,
      497,  484,  501,  500,  502,  506,  499,    0,  498,  494,
      494,  513,  503,    0,  509,  504,  514,  525,  519,  521,
      528,  527,  519,  533,  534,    0,  538,  531,  532,    0,
      539,  547,  545,  543,    0,    0,    0,  549,  549,    0,
        0,  543,  546,    0,    0,    0,    0,  552,    0,  548,
      556,  558,  572,  569,  559,  568,  567,  570,    0,  566,
      571,  589,  581,  590,  579,  597,  589,  586,    0,  593,
        0,  590,    0,  597,  603,  595,    0,    0,  614,  615,

      606,    0,    0,  610,    0,  623,  620,  609,  625,  607,
        0,  623,  620,    0,    0,    0,  633,  629,    0,    0,
      629,  635,    0,    0,    0,    0,  629,  643,  644,  635,
      643,  643,  648,    0,    0,  650,    0,  637,    0,  645,
      647,  663,  653,  658,  669,    0,    0,    0,  664,  667,
        0,  673,  672,  666,  668,    0,    0,    0,    0,  677,
      687,  676,  688,    0,    0,  684,  685,  690,  697,    0,
        0,    0,  769,  743,  748,  751,  754,   87,   80,  757,
      760,  764
    } ;

static yyconst flex_int16_t yy_def[383] =
    {   0,
      373,    1,  374,  374,  373,  373,  373,  373,  373,  375,
      373,  373,  373,  373,  373,  373,  376,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  377,  378,  373,  373,  373,  373,
      373,  375,  373,  375,  373,  373,  373,  373,  373,  373,
      373,  373,  379,  380,  380,  380,  380,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,

      377,  377,  377,  377,  377,  377,  377,  377,  377,  381,
      373,  375,  382,  380,  380,  380,  380,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  381,  373,  382,  380,  380,  377,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,

      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,  380,  380,  377,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      380,  380,  377,  377,  377,  377,  377,  377,  377,  377,

      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  380,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,    0,  373,  373,  373,  373,  373,  373,  373,
      373,  373
    } ;

static yyconst flex_int16_t yy_nxt[835] =
    {   0,
        6,    7,    8,    9,   10,    6,   11,   12,   13,   14,
       15,    6,   16,   17,   18,   19,   20,   21,   22,   23,
       24,   22,   25,   22,   22,   26,   27,   28,   29,   22,
       30,   31,   32,   33,   34,   35,   22,   22,   22,    6,
       36,   18,   19,   20,   21,   22,   23,   24,   22,   25,
       22,   26,   27,   28,   29,   22,   30,   31,   32,   33,
       34,   35,   22,   22,   22,   38,   38,   43,   39,   39,
       40,   40,   40,   40,   47,  373,   48,   50,   51,   53,
       59,   63,   55,  113,   60,   61,   43,   62,   56,   65,
      110,   80,   68,  183,   75,   81,   69,   40,   40,   76,

       64,   57,   44,   66,   70,   67,   59,  183,   63,   55,
       60,   61,  112,   62,  105,   56,   65,   71,   80,   68,
       75,   44,   81,   69,   77,   76,   64,   57,   72,   66,
       70,   67,  115,   73,   78,   47,   74,   48,   79,   82,
       45,  105,   86,   83,   71,   89,   90,   84,   45,  111,
      103,   77,  104,   85,   72,   52,   87,  116,  115,   73,
       78,   88,   74,   91,   79,  117,   82,   92,  118,   86,
       83,   89,   90,  120,   84,  100,  103,   93,  104,   85,
      124,   94,   87,  119,  116,  121,   49,   88,   46,  101,
       91,  102,  117,  106,   92,  118,   45,  107,  128,  120,

      108,  109,  100,   93,  122,   41,  124,   94,   95,  373,
      119,   96,  121,  125,  126,  101,  123,  102,   97,  133,
      106,  127,   98,   99,  107,  128,  129,  108,  109,  134,
      131,  122,  130,  132,  137,   95,  135,  138,   96,  125,
      126,  136,  123,  139,   97,  133,  140,  127,   98,   99,
      141,  151,  129,  144,  145,  134,  131,  146,  130,  132,
      137,  149,  135,  138,  142,  143,  147,  136,  150,  139,
      148,  152,  140,  153,  154,  155,  156,  141,  151,  144,
      145,  157,  162,  146,  161,  373,  169,  149,  167,  168,
      142,  143,  147,  158,  150,  170,  148,  152,  171,  153,

      154,  155,  174,  156,  172,  175,  179,  157,  159,  162,
      161,  160,  163,  169,  167,  168,  178,  164,  165,  166,
      158,  170,  176,  173,  180,  171,  181,  177,   43,  174,
      185,  172,  175,  179,  159,  186,  373,  160,  163,  187,
      188,  194,  178,  164,  165,  166,  189,  190,  176,  173,
      191,  180,  181,  177,  192,  193,  185,  195,  196,  373,
      197,  198,  186,   44,  199,  200,  187,  188,  194,  201,
      202,  203,  189,  190,  204,  206,  191,  205,  207,  210,
      192,  193,  208,  209,  195,  196,  197,  198,  211,  212,
      199,  213,  200,  214,  216,  201,  202,  215,  203,  217,

      218,  204,  206,  205,  219,  207,  210,  220,  208,  209,
      222,  223,  224,  227,  221,  211,  212,  225,  213,  226,
      214,  216,  228,  215,  229,  234,  217,  218,  230,  232,
      231,  219,  233,  235,  220,  236,  222,  223,  224,  227,
      221,  237,  238,  240,  225,  239,  226,  241,  228,  242,
      244,  229,  234,  243,  230,  232,  231,  245,  233,  235,
      246,  247,  236,  248,  249,  373,  250,  237,  251,  238,
      240,  239,  252,  241,  253,  254,  242,  244,  255,  243,
      256,  257,  373,  258,  245,  259,  246,  260,  247,  261,
      248,  249,  250,  262,  251,  263,  373,  264,  252,  265,

      253,  266,  254,  267,  268,  255,  256,  269,  257,  258,
      270,  271,  259,  260,  272,  261,  273,  274,  275,  262,
      276,  277,  263,  264,  278,  265,  279,  280,  266,  267,
      268,  281,  285,  269,  282,  283,  284,  270,  271,  286,
      272,  287,  288,  273,  274,  275,  289,  276,  277,  290,
      278,  291,  279,  280,  292,  293,  294,  297,  281,  285,
      282,  283,  284,  295,  296,  298,  286,  299,  287,  288,
      300,  301,  307,  289,  302,  303,  290,  291,  304,  305,
      306,  292,  293,  294,  297,  308,  309,  310,  314,  295,
      296,  311,  298,  312,  299,  313,  300,  315,  301,  307,

      302,  303,  316,  317,  304,  305,  306,  318,  319,  373,
      320,  308,  321,  309,  310,  314,  322,  311,  323,  312,
      324,  313,  325,  315,  326,  327,  373,  328,  316,  329,
      317,  330,  332,  318,  331,  319,  320,  333,  334,  321,
      335,  336,  322,  337,  323,  338,  324,  339,  325,  340,
      326,  341,  327,  328,  342,  343,  329,  344,  330,  332,
      331,  345,  346,  350,  333,  334,  335,  347,  336,  337,
      348,  349,  338,  339,  351,  352,  340,  353,  341,  354,
      342,  355,  343,  344,  356,  357,  358,  361,  345,  346,
      350,  359,  360,  347,  362,  365,  348,  349,  363,  364,

      351,  352,  366,  353,  367,  354,  368,  371,  355,  369,
      356,  357,  370,  358,  361,  372,  373,  359,  360,  373,
      373,  362,  365,  373,  363,  364,  373,  373,  373,  366,
      367,  373,  373,  368,  371,  369,  373,  373,  370,  373,
      373,  373,  372,   37,   37,   37,   37,   37,   42,   42,
       42,   42,   42,   54,   54,   58,  373,   58,  114,  373,
      114,  182,  373,  182,  182,  184,  373,  184,    5,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,

      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  373,  373
    } ;

static yyconst flex_int16_t yy_chk[835] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    3,    4,   10,    3,    4,
        7,    7,    8,    8,   13,   44,   13,   15,   15,   17,
       18,   19,   17,  379,   18,   18,   42,   18,   17,   20,
      378,   26,   21,  182,   24,   26,   21,   40,   40,   24,

       19,   17,   10,   20,   21,   20,   18,  110,   19,   17,
       18,   18,   44,   18,   34,   17,   20,   23,   26,   21,
       24,   42,   26,   21,   25,   24,   19,   17,   23,   20,
       21,   20,   55,   23,   25,   48,   23,   48,   25,   27,
       47,   34,   28,   27,   23,   29,   29,   27,   45,   39,
       33,   25,   33,   27,   23,   16,   28,   56,   55,   23,
       25,   28,   23,   30,   25,   57,   27,   30,   59,   28,
       27,   29,   29,   61,   27,   32,   33,   30,   33,   27,
       65,   30,   28,   60,   56,   62,   14,   28,   12,   32,
       30,   32,   57,   35,   30,   59,   11,   35,   67,   61,

       35,   35,   32,   30,   63,    9,   65,   30,   31,    5,
       60,   31,   62,   66,   66,   32,   63,   32,   31,   70,
       35,   66,   31,   31,   35,   67,   68,   35,   35,   71,
       69,   63,   68,   69,   73,   31,   72,   74,   31,   66,
       66,   72,   63,   75,   31,   70,   76,   66,   31,   31,
       78,   85,   68,   79,   80,   71,   69,   81,   68,   69,
       73,   83,   72,   74,   78,   78,   82,   72,   84,   75,
       82,   86,   76,   87,   88,   89,   90,   78,   85,   79,
       80,   91,   94,   81,   93,    0,   98,   83,   96,   97,
       78,   78,   82,   92,   84,   99,   82,   86,  100,   87,

       88,   89,  103,   90,  102,  104,  107,   91,   92,   94,
       93,   92,   95,   98,   96,   97,  106,   95,   95,   95,
       92,   99,  105,  102,  108,  100,  109,  105,  112,  103,
      115,  102,  104,  107,   92,  117,    0,   92,   95,  120,
      122,  128,  106,   95,   95,   95,  123,  124,  105,  102,
      125,  108,  109,  105,  126,  127,  115,  129,  130,    0,
      131,  133,  117,  112,  134,  135,  120,  122,  128,  136,
      137,  138,  123,  124,  139,  141,  125,  140,  142,  145,
      126,  127,  143,  144,  129,  130,  131,  133,  146,  147,
      134,  149,  135,  152,  155,  136,  137,  154,  138,  156,

      157,  139,  141,  140,  158,  142,  145,  159,  143,  144,
      160,  161,  162,  165,  159,  146,  147,  163,  149,  164,
      152,  155,  167,  154,  168,  173,  156,  157,  169,  171,
      169,  158,  172,  174,  159,  175,  160,  161,  162,  165,
      159,  176,  177,  179,  163,  178,  164,  180,  167,  181,
      186,  168,  173,  185,  169,  171,  169,  187,  172,  174,
      188,  189,  175,  191,  192,    0,  193,  176,  194,  177,
      179,  178,  195,  180,  196,  197,  181,  186,  199,  185,
      200,  201,    0,  203,  187,  204,  188,  205,  189,  206,
      191,  192,  193,  207,  194,  209,    0,  210,  195,  211,

      196,  212,  197,  214,  216,  199,  200,  217,  201,  203,
      220,  221,  204,  205,  222,  206,  223,  224,  225,  207,
      226,  227,  209,  210,  229,  211,  230,  231,  212,  214,
      216,  232,  237,  217,  233,  235,  236,  220,  221,  238,
      222,  239,  240,  223,  224,  225,  241,  226,  227,  242,
      229,  243,  230,  231,  244,  245,  247,  251,  232,  237,
      233,  235,  236,  248,  249,  252,  238,  253,  239,  240,
      254,  258,  271,  241,  259,  262,  242,  243,  263,  268,
      270,  244,  245,  247,  251,  272,  273,  274,  278,  248,
      249,  275,  252,  276,  253,  277,  254,  280,  258,  271,

      259,  262,  281,  282,  263,  268,  270,  283,  284,    0,
      285,  272,  286,  273,  274,  278,  287,  275,  288,  276,
      290,  277,  292,  280,  294,  295,    0,  296,  281,  299,
      282,  300,  304,  283,  301,  284,  285,  306,  307,  286,
      308,  309,  287,  310,  288,  312,  290,  313,  292,  317,
      294,  318,  295,  296,  321,  322,  299,  327,  300,  304,
      301,  328,  329,  333,  306,  307,  308,  330,  309,  310,
      331,  332,  312,  313,  336,  338,  317,  340,  318,  341,
      321,  342,  322,  327,  343,  344,  345,  352,  328,  329,
      333,  349,  350,  330,  353,  360,  331,  332,  354,  355,

      336,  338,  361,  340,  362,  341,  363,  368,  342,  366,
      343,  344,  367,  345,  352,  369,    0,  349,  350,    0,
        0,  353,  360,    0,  354,  355,    0,    0,    0,  361,
      362,    0,    0,  363,  368,  366,    0,    0,  367,    0,
        0,    0,  369,  374,  374,  374,  374,  374,  375,  375,
      375,  375,  375,  376,  376,  377,    0,  377,  380,    0,
      380,  381,    0,  381,  381,  382,    0,  382,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,

      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  373,  373
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "sphinxql.l"
#line 2 "sphinxql.l"
#include "yysphinxql.h"

#if USE_WINDOWS
#pragma warning(push,1)
#endif

// warning, lexer generator dependent!
// this macro relies on that in flex yytext points to the actual location in the buffer
#define YYSTOREBOUNDS \
	{ \
		lvalp->m_iStart = yytext - pParser->m_pBuf; \
		lvalp->m_iEnd = lvalp->m_iStart + yyleng; \
		pParser->m_pLastTokenStart = yytext; \
	}


#line 759 "llsphinxql.c"

#define INITIAL 0
#define ccomment 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#if !USE_WINDOWS
#include <unistd.h>
#endif
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    }; /* end struct yyguts_t */

static int yy_init_globals (yyscan_t yyscanner );

int yylex_init (yyscan_t* scanner);

int yylex_init_extra (YY_EXTRA_TYPE user_defined,yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (yyscan_t yyscanner );

int yyget_debug (yyscan_t yyscanner );

void yyset_debug (int debug_flag ,yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra (yyscan_t yyscanner );

void yyset_extra (YY_EXTRA_TYPE user_defined ,yyscan_t yyscanner );

FILE *yyget_in (yyscan_t yyscanner );

void yyset_in  (FILE * in_str ,yyscan_t yyscanner );

FILE *yyget_out (yyscan_t yyscanner );

void yyset_out  (FILE * out_str ,yyscan_t yyscanner );

int yyget_leng (yyscan_t yyscanner );

char *yyget_text (yyscan_t yyscanner );

int yyget_lineno (yyscan_t yyscanner );

void yyset_lineno (int line_number ,yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (yyscan_t yyscanner );
#else
extern int yywrap (yyscan_t yyscanner );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int ,yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * ,yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (yyscan_t yyscanner );
#else
static int input (yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (yyscan_t yyscanner);

#define YY_DECL int yylex (yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

#line 29 "sphinxql.l"


#line 982 "llsphinxql.c"

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
		}

		yy_load_buffer_state(yyscanner );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 374 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 769 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 31 "sphinxql.l"
{ BEGIN(ccomment); }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 32 "sphinxql.l"
{ }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 33 "sphinxql.l"
{ BEGIN(INITIAL); }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 35 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_AND; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 36 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_AS; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 37 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ASC; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 38 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ATTACH; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 39 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_AVG; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 40 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BEGIN; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 41 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BETWEEN; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 42 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BY; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 43 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_CALL; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 44 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COLLATION; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 45 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COMMIT; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 46 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COMMITTED; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 47 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COUNT; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 48 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_CREATE; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 49 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DELETE; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 50 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DESC; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 51 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DESCRIBE; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 52 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DISTINCT; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 53 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DIV; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 54 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DROP; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 55 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FALSE; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 56 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FLOAT; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 57 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FLUSH; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 58 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FROM; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 59 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FUNCTION; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 60 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GLOBAL; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 61 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GROUP; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 62 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ID; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 63 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_IN; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 64 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INDEX; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 65 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INSERT; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 66 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INT; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 67 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INTO; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 68 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ISOLATION; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 69 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_LEVEL; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 70 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_LIMIT; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 71 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MATCH; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 72 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MAX; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 73 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_META; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 74 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MIN; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 75 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MOD; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 76 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NAMES; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 77 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NOT; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 78 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NULL; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 79 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_OPTION; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 80 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_OR; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 81 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ORDER; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 82 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RAND; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 83 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_READ; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 84 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_REPEATABLE; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 85 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_REPLACE; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 86 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RETURNS; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 87 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ROLLBACK; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 88 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RTINDEX; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 89 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SELECT; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 90 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SERIALIZABLE; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 91 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SET; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 92 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SESSION; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 93 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SHOW; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 94 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SONAME; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 95 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_START; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 96 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_STATUS; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 97 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SUM; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 98 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TABLES; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 99 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TO; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 100 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TRANSACTION; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 101 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TRUE; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 102 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_UNCOMMITTED; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 103 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_UPDATE; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 104 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_VALUES; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 105 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_VARIABLES; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 106 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_WARNINGS; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 107 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_WEIGHT; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 108 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_WHERE; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 109 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_WITHIN; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 111 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NE; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 112 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NE; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 113 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_LTE; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 114 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GTE; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 115 "sphinxql.l"
{ YYSTOREBOUNDS; return '='; }
	YY_BREAK
case 84:
/* rule 84 can match eol */
YY_RULE_SETUP
#line 117 "sphinxql.l"
{ YYSTOREBOUNDS; SqlUnescape ( lvalp->m_sValue, yytext, yyleng ); return TOK_QUOTED_STRING; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 119 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_sValue = yytext; lvalp->m_fValue = (float)strtod ( yytext, NULL ); return TOK_CONST_FLOAT; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 120 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_sValue = yytext; lvalp->m_iValue = strtoll ( yytext, NULL, 10 ); return TOK_CONST_INT; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 122 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_sValue = yytext; return TOK_ATIDENT; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 123 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_sValue = yytext; return TOK_ATIDENT; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 124 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_sValue = yytext; return TOK_ATIDENT; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 125 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_sValue = yytext; return TOK_IDENT; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 126 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_sValue = yytext; return TOK_USERVAR; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 127 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_sValue = yytext; return TOK_SYSVAR; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 128 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_iStart++; lvalp->m_iEnd--; lvalp->m_sValue.SetBinary ( yytext+1, strlen(yytext)-2 ); return TOK_IDENT; }
	YY_BREAK
case 94:
/* rule 94 can match eol */
YY_RULE_SETUP
#line 130 "sphinxql.l"
{ ; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 131 "sphinxql.l"
{ YYSTOREBOUNDS; return yytext[0]; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 133 "sphinxql.l"
ECHO;
	YY_BREAK
#line 1547 "llsphinxql.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(ccomment):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap(yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = yyg->yytext_ptr;
	register int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2 ,yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  ,yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) (yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size ,yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 374 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	register int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	register char *yy_cp = yyg->yy_c_buf_p;

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 374 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 373);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = yyg->yy_c_buf_p - yyg->yytext_ptr;
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin ,yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(yyscanner ) )
						return EOF;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file ,yyscanner);
	yy_load_buffer_state(yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2 ,yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file ,yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf ,yyscanner );

	yyfree((void *) b ,yyscanner );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer(b ,yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	int num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b ,yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes(yystr,strlen(yystr) ,yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n ,yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n ,yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg , yyscan_t yyscanner)
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           yy_fatal_error( "yyset_lineno called with no buffer" , yyscanner); 
    
    yylineno = line_number;
}

/** Set the current column.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           yy_fatal_error( "yyset_column called with no buffer" , yyscanner); 
    
    yycolumn = column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = in_str ;
}

void yyset_out (FILE *  out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = bdebug ;
}

/* Accessor methods for yylval and yylloc */

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */

int yylex_init(yyscan_t* ptr_yy_globals)

{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */

int yylex_init_extra(YY_EXTRA_TYPE yy_user_defined,yyscan_t* ptr_yy_globals )

{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }
	
    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );
	
    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }
    
    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));
    
    yyset_extra (yy_user_defined, *ptr_yy_globals);
    
    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = 0;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = (char *) 0;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack ,yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree(yyg->yy_start_stack ,yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n , yyscan_t yyscanner)
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s , yyscan_t yyscanner)
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 133 "sphinxql.l"



// warning, lexer generator dependent!
// flex inserts trailing zero as needed into the buffer when lexing
// but we need that rolled back when doing error reporting from yyerror
void yylex_unhold ( yyscan_t yyscanner )
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( YY_CURRENT_BUFFER )
	{
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
	}
}

#if USE_WINDOWS
#pragma warning(pop)
#endif

